@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qttableview.cpp,v 1.1 2001/10/19 18:53:05 bruggie Exp $
+** $Id: qttableview.cpp 741064 2007-11-24 17:57:19Z woebbe $
 **
 ** Implementation of QtTableView class
 **
@@ -13,9 +13,11 @@
 **********************************************************************/
 
 #include "qttableview.h"
-#include "qscrollbar.h"
-#include "qpainter.h"
-#include "qdrawutil.h"
+#include <qapplication.h>
+#include <qdrawutil.h>
+#include <qevent.h>
+#include <qpainter.h>
+#include <qscrollbar.h>
 #include <limits.h>
 
 enum ScrollBarDirtyFlags {
@@ -39,17 +41,13 @@ enum ScrollBarDirtyFlags {
 class QCornerSquare : public QWidget		// internal class
 {
 public:
-    QCornerSquare( QWidget *, const char* = 0 );
-    void paintEvent( QPaintEvent * );
+    QCornerSquare( QWidget * );
 };
 
-QCornerSquare::QCornerSquare( QWidget *parent, const char *name )
-	: QWidget( parent, name )
-{
-}
-
-void QCornerSquare::paintEvent( QPaintEvent * )
+QCornerSquare::QCornerSquare( QWidget *parent )
+	: QWidget( parent )
 {
+    setAutoFillBackground( true );
 }
 
 
@@ -106,7 +104,7 @@ void QCornerSquare::paintEvent( QPaintEvent * )
   \warning the functions setNumRows(), setNumCols(), setCellHeight(),
   setCellWidth(), setTableFlags() and clearTableFlags() may cause
   virtual functions such as cellWidth() and cellHeight() to be called,
-  even if autoUpdate() is FALSE.  This may cause errors if relevant
+  even if autoUpdate() is 'false'.  This may cause errors if relevant
   state variables are not initialized.
 
   \warning Experience has shown that use of this widget tends to cause
@@ -142,7 +140,7 @@ void QCornerSquare::paintEvent( QPaintEvent * )
 
 */
 
-QtTableView::QtTableView( QWidget *parent, const char *name, WFlags f )
+QtTableView::QtTableView( QWidget *parent, const char *name, Qt::WFlags f )
     : QFrame( parent, name, f )
 {
     nRows		 = nCols      = 0;	// zero rows/cols
@@ -154,13 +152,15 @@ QtTableView::QtTableView( QWidget *parent, const char *name, WFlags f )
     vScrollBar		 = hScrollBar = 0;	// no scroll bars
     cornerSquare	 = 0;
     sbDirty		 = 0;
-    eraseInPaint	 = FALSE;
-    verSliding		 = FALSE;
-    verSnappingOff	 = FALSE;
-    horSliding		 = FALSE;
-    horSnappingOff	 = FALSE;
-    coveringCornerSquare = FALSE;
-    inSbUpdate		 = FALSE;
+    eraseInPaint	 = false;
+    verSliding		 = false;
+    verSnappingOff	 = false;
+    horSliding		 = false;
+    horSnappingOff	 = false;
+    coveringCornerSquare = false;
+    inSbUpdate		 = false;
+
+    setAttribute(Qt::WA_NoBackground, true);
 }
 
 /*!
@@ -175,35 +175,6 @@ QtTableView::~QtTableView()
 }
 
 
-/*!
-  \internal
-  Reimplements QWidget::setBackgroundColor() for binary compatibility.
-  \sa setPalette()
-*/
-
-void QtTableView::setBackgroundColor( const QColor &c )
-{
-    QWidget::setBackgroundColor( c );
-}
-
-/*!\reimp
-*/
-
-void QtTableView::setPalette( const QPalette &p )
-{
-    QWidget::setPalette( p );
-}
-
-/*!\reimp
-*/
-
-void QtTableView::show()
-{
-    showOrHideScrollBars();
-    QWidget::show();
-}
-
-
 /*!
   \overload void QtTableView::repaint( bool erase )
   Repaints the entire view.
@@ -213,7 +184,7 @@ void QtTableView::show()
   Repaints the table view directly by calling paintEvent() directly
   unless updates are disabled.
 
-  Erases the view area \a (x,y,w,h) if \a erase is TRUE. Parameters \a
+  Erases the view area \a (x,y,w,h) if \a erase is 'true'. Parameters \a
   (x,y) are in \e widget coordinates.
 
   If \a w is negative, it is replaced with <code>width() - x</code>.
@@ -230,7 +201,7 @@ void QtTableView::show()
 
 void QtTableView::repaint( int x, int y, int w, int h, bool erase )
 {
-    if ( !isVisible() || testWState(WState_BlockUpdates) )
+    if ( !isVisible() )
 	return;
     if ( w < 0 )
 	w = width()  - x;
@@ -239,16 +210,15 @@ void QtTableView::repaint( int x, int y, int w, int h, bool erase )
     QRect r( x, y, w, h );
     if ( r.isEmpty() )
 	return; // nothing to do
-    QPaintEvent e( r );
-    if ( erase && backgroundMode() != NoBackground )
-	eraseInPaint = TRUE;			// erase when painting
-    paintEvent( &e );
-    eraseInPaint = FALSE;
+    if ( erase && backgroundMode() != Qt::NoBackground )
+	eraseInPaint = true;			// erase when painting
+    QWidget::repaint( r );
+    eraseInPaint = false;
 }
 
 /*!
   \overload void QtTableView::repaint( const QRect &r, bool erase )
-  Replaints rectangle \a r. If \a erase is TRUE draws the background
+  Replaints rectangle \a r. If \a erase is 'true' draws the background
   using the palette's background.
 */
 
@@ -372,7 +342,7 @@ void QtTableView::setLeftCell( int col )
 }
 
 /*!
-  Scrolls the table so that the cell at row \a row and colum \a
+  Scrolls the table so that the cell at row \a row and column \a
   col becomes the top-left cell in the view.  The cell at the extreme
   top left of the table is at position (0,0).
   \sa setLeftCell(), setTopCell(), setOffset()
@@ -462,7 +432,7 @@ void QtTableView::setYOffset( int y )
   in the view. Parameters \a (x,y) are in \e table coordinates.
 
   The interaction with \link setTableFlags() Tbl_snapTo*Grid \endlink
-  is tricky.  If \a updateScrBars is TRUE, the scroll bars are
+  is tricky.  If \a updateScrBars is 'true', the scroll bars are
   updated.
 
   \sa xOffset(), yOffset(), setXOffset(), setYOffset(), setTopLeftCell()
@@ -705,8 +675,8 @@ int QtTableView::totalHeight()
 /*!
   \fn bool QtTableView::testTableFlags( uint f ) const
 
-  Returns TRUE if any of the table flags in \a f are currently set,
-  otherwise FALSE.
+  Returns 'true' if any of the table flags in \a f are currently set,
+  otherwise 'false'.
 
   \sa setTableFlags(), clearTableFlags(), tableFlags()
 */
@@ -715,7 +685,7 @@ int QtTableView::totalHeight()
   Sets the table flags to \a f.
 
   If a flag setting changes the appearance of the table, the table is
-  repainted if - and only if - autoUpdate() is TRUE.
+  repainted if - and only if - autoUpdate() is 'true'.
 
   The table flags are mostly single bits, though there are some multibit
   flags for convenience. Here is a complete list:
@@ -782,15 +752,15 @@ void QtTableView::setTableFlags( uint f )
     tFlags |= f;
 
     bool updateOn = autoUpdate();
-    setAutoUpdate( FALSE );
+    setAutoUpdate( false );
 
     uint repaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
 
     if ( f & Tbl_vScrollBar ) {
-	setVerScrollBar( TRUE );
+	setVerScrollBar( true );
     }
     if ( f & Tbl_hScrollBar ) {
-	setHorScrollBar( TRUE );
+	setHorScrollBar( true );
     }
     if ( f & Tbl_autoVScrollBar ) {
 	updateScrollBars( verRange );
@@ -820,7 +790,7 @@ void QtTableView::setTableFlags( uint f )
     }
 
     if ( updateOn ) {
-	setAutoUpdate( TRUE );
+	setAutoUpdate( true );
 	updateScrollBars();
 	if ( isVisible() && (f & repaintMask) )
 	    repaint();
@@ -848,15 +818,15 @@ void QtTableView::clearTableFlags( uint f )
     tFlags &= ~f;
 
     bool updateOn = autoUpdate();
-    setAutoUpdate( FALSE );
+    setAutoUpdate( false );
 
     uint repaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
 
     if ( f & Tbl_vScrollBar ) {
-	setVerScrollBar( FALSE );
+	setVerScrollBar( false );
     }
     if ( f & Tbl_hScrollBar ) {
-	setHorScrollBar( FALSE );
+	setHorScrollBar( false );
     }
     if ( f & Tbl_scrollLastHCell ) {
 	int maxX = maxXOffset();
@@ -889,7 +859,7 @@ void QtTableView::clearTableFlags( uint f )
 	updateScrollBars( verRange );
     }
     if ( updateOn ) {
-	setAutoUpdate( TRUE );
+	setAutoUpdate( true );
 	updateScrollBars();	     // returns immediately if nothing to do
 	if ( isVisible() && (f & repaintMask) )
 	    repaint();
@@ -901,7 +871,7 @@ void QtTableView::clearTableFlags( uint f )
 /*!
   \fn bool QtTableView::autoUpdate() const
 
-  Returns TRUE if the view updates itself automatically whenever it
+  Returns 'true' if the view updates itself automatically whenever it
   is changed in some way.
 
   \sa setAutoUpdate()
@@ -910,11 +880,11 @@ void QtTableView::clearTableFlags( uint f )
 /*!
   Sets the auto-update option of the table view to \a enable.
 
-  If \a enable is TRUE (this is the default), the view updates itself
+  If \a enable is 'true' (this is the default), the view updates itself
   automatically whenever it has changed in some way (for example, when a
   \link setTableFlags() flag\endlink is changed).
 
-  If \a enable is FALSE, the view does NOT repaint itself or update
+  If \a enable is 'false', the view does NOT repaint itself or update
   its internal state variables when it is changed.  This can be
   useful to avoid flicker during large changes and is singularly
   useless otherwise. Disable auto-update, do the changes, re-enable
@@ -924,7 +894,7 @@ void QtTableView::clearTableFlags( uint f )
   (i.e., between events). If, for example, the user interacts with the
   view when auto-update is off, strange things can happen.
 
-  Setting auto-update to TRUE does not repaint the view; you must call
+  Setting auto-update to 'true' does not repaint the view; you must call
   repaint() to do this.
 
   \sa autoUpdate(), repaint()
@@ -932,7 +902,7 @@ void QtTableView::clearTableFlags( uint f )
 
 void QtTableView::setAutoUpdate( bool enable )
 {
-    if ( isUpdatesEnabled() == enable )
+    if ( updatesEnabled() == enable )
 	return;
     setUpdatesEnabled( enable );
     if ( enable ) {
@@ -945,7 +915,7 @@ void QtTableView::setAutoUpdate( bool enable )
 /*!
   Repaints the cell at row \a row, column \a col if it is inside the view.
 
-  If \a erase is TRUE, the relevant part of the view is cleared to the
+  If \a erase is 'true', the relevant part of the view is cleared to the
   background color/pixmap before the contents are repainted.
 
   \sa isVisible()
@@ -1041,7 +1011,7 @@ int QtTableView::lastColVisible() const
 }
 
 /*!
-  Returns TRUE if \a row is at least partially visible.
+  Returns 'true' if \a row is at least partially visible.
   \sa colIsVisible()
 */
 
@@ -1051,7 +1021,7 @@ bool QtTableView::rowIsVisible( int row ) const
 }
 
 /*!
-  Returns TRUE if \a col is at least partially visible.
+  Returns 'true' if \a col is at least partially visible.
   \sa rowIsVisible()
 */
 
@@ -1091,10 +1061,10 @@ void QtTableView::coverCornerSquare( bool enable )
   \internal
   Scroll the view to a position such that:
 
-  If \a horizontal is TRUE, the leftmost column shown fits snugly
+  If \a horizontal is 'true', the leftmost column shown fits snugly
   with the left edge of the view.
 
-  If \a vertical is TRUE, the top row shown fits snugly with the top
+  If \a vertical is 'true', the top row shown fits snugly with the top
   of the view.
 
   You can achieve the same effect automatically by setting any of the
@@ -1134,13 +1104,13 @@ void QtTableView::snapToGrid( bool horizontal, bool vertical )
 void QtTableView::horSbValue( int val )
 {
     if ( horSliding ) {
-	horSliding = FALSE;
+	horSliding = false;
 	if ( horSnappingOff ) {
-	    horSnappingOff = FALSE;
+	    horSnappingOff = false;
 	    tFlags |= Tbl_snapToHGrid;
 	}
     }
-    setOffset( val, yOffs, FALSE );
+    setOffset( val, yOffs, false );
 }
 
 /*!
@@ -1156,10 +1126,10 @@ void QtTableView::horSbSliding( int val )
     if ( testTableFlags(Tbl_snapToHGrid) &&
 	 testTableFlags(Tbl_smoothHScrolling) ) {
 	tFlags &= ~Tbl_snapToHGrid;	// turn off snapping while sliding
-	setOffset( val, yOffs, FALSE );
+	setOffset( val, yOffs, false );
 	tFlags |= Tbl_snapToHGrid;	// turn on snapping again
     } else {
-	setOffset( val, yOffs, FALSE );
+	setOffset( val, yOffs, false );
     }
 }
 
@@ -1173,7 +1143,7 @@ void QtTableView::horSbSlidingDone( )
 {
     if ( testTableFlags(Tbl_snapToHGrid) &&
 	 testTableFlags(Tbl_smoothHScrolling) )
-	snapToGrid( TRUE, FALSE );
+	snapToGrid( true, false );
 }
 
 /*!
@@ -1188,13 +1158,13 @@ void QtTableView::horSbSlidingDone( )
 void QtTableView::verSbValue( int val )
 {
     if ( verSliding ) {
-	verSliding = FALSE;
+	verSliding = false;
 	if ( verSnappingOff ) {
-	    verSnappingOff = FALSE;
+	    verSnappingOff = false;
 	    tFlags |= Tbl_snapToVGrid;
 	}
     }
-    setOffset( xOffs, val, FALSE );
+    setOffset( xOffs, val, false );
 }
 
 /*!
@@ -1210,10 +1180,10 @@ void QtTableView::verSbSliding( int val )
     if ( testTableFlags(Tbl_snapToVGrid) &&
 	 testTableFlags(Tbl_smoothVScrolling) ) {
 	tFlags &= ~Tbl_snapToVGrid;	// turn off snapping while sliding
-	setOffset( xOffs, val, FALSE );
+	setOffset( xOffs, val, false );
 	tFlags |= Tbl_snapToVGrid;	// turn on snapping again
     } else {
-	setOffset( xOffs, val, FALSE );
+	setOffset( xOffs, val, false );
     }
 }
 
@@ -1227,7 +1197,7 @@ void QtTableView::verSbSlidingDone( )
 {
     if ( testTableFlags(Tbl_snapToVGrid) &&
 	 testTableFlags(Tbl_smoothVScrolling) )
-	snapToGrid( FALSE, TRUE );
+	snapToGrid( false, true );
 }
 
 
@@ -1278,7 +1248,7 @@ void QtTableView::paintEvent( QPaintEvent *e )
 
     QPainter paint( this );
 
-    if ( !contentsRect().contains( updateR, TRUE  ) ) {// update frame ?
+    if ( !contentsRect().contains( updateR, true  ) ) {// update frame ?
 	drawFrame( &paint );
 	if ( updateR.left() < frameWidth() ) 		//###
 	    updateR.setLeft( frameWidth() );
@@ -1314,7 +1284,7 @@ void QtTableView::paintEvent( QPaintEvent *e )
     QRect cellR;
     QRect cellUR;
 #ifndef QT_NO_TRANSFORMATIONS
-    QWMatrix matrix;
+    QMatrix matrix;
 #endif
 
     while ( yPos <= maxY && row < nRows ) {
@@ -1339,24 +1309,27 @@ void QtTableView::paintEvent( QPaintEvent *e )
 
 #ifndef QT_NO_TRANSFORMATIONS
 		matrix.translate( xPos, yPos );
-		paint.setWorldMatrix( matrix );
+		paint.setMatrix( matrix );
 		if ( testTableFlags(Tbl_clipCellPainting) ||
 		     frameWidth() > 0 && !winR.contains( cellR ) ) { //##arnt
-		    paint.setClipRect( cellUR );
+#ifdef __GNUC__
+#warning disable clipping for now as it interferes with drawText() in DiffView::paintCell()
+#endif
+// 		    paint.setClipRect( cellUpdateR );
 		    paintCell( &paint, row, col );
-		    paint.setClipping( FALSE );
+// 		    paint.setClipping( false );
 		} else {
 		    paintCell( &paint, row, col );
 		}
 		matrix.reset();
-		paint.setWorldMatrix( matrix );
+		paint.setMatrix( matrix );
 #else
 		paint.translate( xPos, yPos );
 		if ( testTableFlags(Tbl_clipCellPainting) ||
 		     frameWidth() > 0 && !winR.contains( cellR ) ) { //##arnt
-		    paint.setClipRect( cellUR );
+		    paint.setClipRect( cellUpdateR );
 		    paintCell( &paint, row, col );
-		    paint.setClipping( FALSE );
+		    paint.setClipping( false );
 		} else {
 		    paintCell( &paint, row, col );
 		}
@@ -1377,13 +1350,13 @@ void QtTableView::paintEvent( QPaintEvent *e )
 
     // Note that this needs to be done regardless whether we do
     // eraseInPaint or not. Reason: a subclass may implement
-    // flicker-freeness and encourage the use of repaint(FALSE).
+    // flicker-freeness and encourage the use of repaint(false).
     // The subclass, however, cannot draw all pixels, just those
     // inside the cells. So QtTableView is reponsible for all pixels
     // outside the cells.
 
     QRect viewR = viewRect();
-    const QColorGroup g = colorGroup();
+    QPalette g = palette();
 
     if ( xPos <= maxX ) {
 	QRect r = viewR;
@@ -1412,11 +1385,22 @@ void QtTableView::resizeEvent( QResizeEvent * )
 		      verSteps | verGeometry | verRange );
     showOrHideScrollBars();
     updateFrameSize();
-    int maxX = QMIN( xOffs, maxXOffset() );			// ### can be slow
-    int maxY = QMIN( yOffs, maxYOffset() );
+    int maxX = qMin( xOffs, maxXOffset() );			// ### can be slow
+    int maxY = qMin( yOffs, maxYOffset() );
     setOffset( maxX, maxY );
 }
 
+void QtTableView::showEvent( QShowEvent * e )
+{
+    showOrHideScrollBars();
+    QFrame::showEvent( e );
+}
+
+void QtTableView::wheelEvent( QWheelEvent * e )
+{
+    if( e->orientation() == Qt::Vertical && vScrollBar && vScrollBar->isVisible() )
+        QApplication::sendEvent( vScrollBar, e );
+}
 
 /*!
   Redraws all visible cells in the table view.
@@ -1437,14 +1421,16 @@ QScrollBar *QtTableView::verticalScrollBar() const
 {
     QtTableView *that = (QtTableView*)this; // semantic const
     if ( !vScrollBar ) {
-	QScrollBar *sb = new QScrollBar( QScrollBar::Vertical, that );
+	QScrollBar *sb = new QScrollBar( Qt::Vertical, that );
+	sb->setAttribute(Qt::WA_NoMousePropagation);
+	sb->setAutoFillBackground(true);
 #ifndef QT_NO_CURSOR
-	sb->setCursor( arrowCursor );
+	sb->setCursor( Qt::ArrowCursor );
 #endif
         sb->resize( sb->sizeHint() ); // height is irrelevant
 	Q_CHECK_PTR(sb);
-	sb->setTracking( FALSE );
-	sb->setFocusPolicy( NoFocus );
+	sb->setTracking( false );
+	sb->setFocusPolicy( Qt::NoFocus );
 	connect( sb, SIGNAL(valueChanged(int)),
 		 SLOT(verSbValue(int)));
 	connect( sb, SIGNAL(sliderMoved(int)),
@@ -1468,14 +1454,15 @@ QScrollBar *QtTableView::horizontalScrollBar() const
 {
     QtTableView *that = (QtTableView*)this; // semantic const
     if ( !hScrollBar ) {
-	QScrollBar *sb = new QScrollBar( QScrollBar::Horizontal, that );
+	QScrollBar *sb = new QScrollBar( Qt::Horizontal, that );
+	sb->setAutoFillBackground(true);
 #ifndef QT_NO_CURSOR
-	sb->setCursor( arrowCursor );
+	sb->setCursor( Qt::ArrowCursor );
 #endif
 	sb->resize( sb->sizeHint() ); // width is irrelevant
-	sb->setFocusPolicy( NoFocus );
+	sb->setFocusPolicy( Qt::NoFocus );
 	Q_CHECK_PTR(sb);
-	sb->setTracking( FALSE );
+	sb->setTracking( false );
 	connect( sb, SIGNAL(valueChanged(int)),
 		 SLOT(horSbValue(int)));
 	connect( sb, SIGNAL(sliderMoved(int)),
@@ -1504,14 +1491,14 @@ void QtTableView::setHorScrollBar( bool on, bool update )
 	else
 	    sbDirty = sbDirty | (horMask | verMask);
 	if ( testTableFlags( Tbl_vScrollBar ) )
-	    coverCornerSquare( TRUE );
+	    coverCornerSquare( true );
 	if ( autoUpdate() )
 	    sbDirty = sbDirty | horMask;
     } else {
 	tFlags &= ~Tbl_hScrollBar;
 	if ( !hScrollBar )
 	    return;
-	coverCornerSquare( FALSE );
+	coverCornerSquare( false );
 	bool hideScrollBar = autoUpdate() && hScrollBar->isVisible();
 	if ( hideScrollBar )
 	    hScrollBar->hide();
@@ -1543,14 +1530,14 @@ void QtTableView::setVerScrollBar( bool on, bool update )
 	else
 	    sbDirty = sbDirty | (horMask | verMask);
 	if ( testTableFlags( Tbl_hScrollBar ) )
-	    coverCornerSquare( TRUE );
+	    coverCornerSquare( true );
 	if ( autoUpdate() )
 	    sbDirty = sbDirty | verMask;
     } else {
 	tFlags &= ~Tbl_vScrollBar;
 	if ( !vScrollBar )
 	    return;
-	coverCornerSquare( FALSE );
+	coverCornerSquare( false );
 	bool hideScrollBar = autoUpdate() && vScrollBar->isVisible();
 	if ( hideScrollBar )
 	    vScrollBar->hide();
@@ -1705,8 +1692,8 @@ int QtTableView::findCol( int xPos ) const
 /*!
   Computes the position in the widget of row \a row.
 
-  Returns TRUE and stores the result in \a *yPos (in \e widget
-  coordinates) if the row is visible.  Returns FALSE and does not modify
+  Returns 'true' and stores the result in \a *yPos (in \e widget
+  coordinates) if the row is visible.  Returns 'false' and does not modify
   \a *yPos if \a row is invisible or invalid.
 
   \sa colXPos(), findRow()
@@ -1719,7 +1706,7 @@ bool QtTableView::rowYPos( int row, int *yPos ) const
 	if ( cellH ) {
 	    int lastVisible = lastRowVisible();
 	    if ( row > lastVisible || lastVisible == -1 )
-		return FALSE;
+		return false;
 	    y = (row - yCellOffs)*cellH + minViewY() - yCellDelta;
 	} else {
 	    //##arnt3
@@ -1730,23 +1717,23 @@ bool QtTableView::rowYPos( int row, int *yPos ) const
 	    while ( r < row && y <= maxY )
 		y += tw->cellHeight( r++ );
 	    if ( y > maxY )
-		return FALSE;
+		return false;
 
 	}
     } else {
-	return FALSE;
+	return false;
     }
     if ( yPos )
 	*yPos = y;
-    return TRUE;
+    return true;
 }
 
 
 /*!
   Computes the position in the widget of column \a col.
 
-  Returns TRUE and stores the result in \a *xPos (in \e widget
-  coordinates) if the column is visible.  Returns FALSE and does not
+  Returns 'true' and stores the result in \a *xPos (in \e widget
+  coordinates) if the column is visible.  Returns 'false' and does not
   modify \a *xPos if \a col is invisible or invalid.
 
   \sa rowYPos(), findCol()
@@ -1759,7 +1746,7 @@ bool QtTableView::colXPos( int col, int *xPos ) const
 	if ( cellW ) {
 	    int lastVisible = lastColVisible();
 	    if ( col > lastVisible || lastVisible == -1 )
-		return FALSE;
+		return false;
 	    x = (col - xCellOffs)*cellW + minViewX() - xCellDelta;
 	} else {
 	    //##arnt3
@@ -1770,14 +1757,14 @@ bool QtTableView::colXPos( int col, int *xPos ) const
 	    while ( c < col && x <= maxX )
 		x += tw->cellWidth( c++ );
 	    if ( x > maxX )
-		return FALSE;
+		return false;
 	}
     } else {
-	return FALSE;
+	return false;
     }
     if ( xPos )
 	*xPos = x;
-    return TRUE;
+    return true;
 }
 
 
@@ -1906,9 +1893,9 @@ void QtTableView::doAutoScrollBars()
 		w += cellWidth( i++ );
 	}
 	if ( w > viewW )
-	    hScrollOn = TRUE;
+	    hScrollOn = true;
 	else
-	    hScrollOn = FALSE;
+	    hScrollOn = false;
     }
 
     if ( testTableFlags(Tbl_autoVScrollBar) ) {
@@ -1921,21 +1908,21 @@ void QtTableView::doAutoScrollBars()
 	}
 
 	if ( h > viewH )
-	    vScrollOn = TRUE;
+	    vScrollOn = true;
 	else
-	    vScrollOn = FALSE;
+	    vScrollOn = false;
     }
 
     if ( testTableFlags(Tbl_autoHScrollBar) && vScrollOn && !hScrollOn )
 	if ( w > viewW - VSBEXT )
-	    hScrollOn = TRUE;
+	    hScrollOn = true;
 
     if ( testTableFlags(Tbl_autoVScrollBar) && hScrollOn && !vScrollOn )
 	if ( h > viewH - HSBEXT )
-	    vScrollOn = TRUE;
+	    vScrollOn = true;
 
-    setHorScrollBar( hScrollOn, FALSE );
-    setVerScrollBar( vScrollOn, FALSE );
+    setHorScrollBar( hScrollOn, false );
+    setVerScrollBar( vScrollOn, false );
     updateFrameSize();
 }
 
@@ -1961,7 +1948,7 @@ void QtTableView::updateScrollBars( uint f )
     sbDirty = sbDirty | f;
     if ( inSbUpdate )
 	return;
-    inSbUpdate = TRUE;
+    inSbUpdate = true;
 
     if ( testTableFlags(Tbl_autoHScrollBar) && (sbDirty & horRange) ||
 	 testTableFlags(Tbl_autoVScrollBar) && (sbDirty & verRange) )
@@ -1969,7 +1956,7 @@ void QtTableView::updateScrollBars( uint f )
 	doAutoScrollBars();		// turn scroll bars on/off if needed
 
     if ( !autoUpdate() ) {
-	inSbUpdate = FALSE;
+	inSbUpdate = false;
 	return;
     }
     if ( yOffset() > 0 && testTableFlags( Tbl_autoVScrollBar ) &&
@@ -1981,7 +1968,7 @@ void QtTableView::updateScrollBars( uint f )
 	setXOffset( 0 );
     }
     if ( !isVisible() ) {
-	inSbUpdate = FALSE;
+	inSbUpdate = false;
 	return;
     }
 
@@ -1993,7 +1980,7 @@ void QtTableView::updateScrollBars( uint f )
 
 	if ( sbDirty & horSteps ) {
 	    if ( cellW )
-		hScrollBar->setSteps( QMIN(cellW,viewWidth()/2), viewWidth() );
+		hScrollBar->setSteps( qMin((int)cellW,viewWidth()/2), viewWidth() );
 	    else
 		hScrollBar->setSteps( 16, viewWidth() );
 	}
@@ -2017,7 +2004,7 @@ void QtTableView::updateScrollBars( uint f )
 
 	if ( sbDirty & verSteps ) {
 	    if ( cellH )
-		vScrollBar->setSteps( QMIN(cellH,viewHeight()/2), viewHeight() );
+		vScrollBar->setSteps( qMin((int)cellH,viewHeight()/2), viewHeight() );
 	    else
 		vScrollBar->setSteps( 16, viewHeight() );  // fttb! ###
 	}
@@ -2038,7 +2025,7 @@ void QtTableView::updateScrollBars( uint f )
 			    maxViewY() + frameWidth() + 1 );
 
     sbDirty = 0;
-    inSbUpdate = FALSE;
+    inSbUpdate = false;
 }
 
 
@@ -2059,9 +2046,9 @@ void QtTableView::updateFrameSize()
 	setFrameRect( QRect(0,0,rw,rh) );
 
 	if ( rw != fw )
-	    update( QMIN(fw,rw) - frameWidth() - 2, 0, frameWidth()+4, rh );
+	    update( qMin(fw,rw) - frameWidth() - 2, 0, frameWidth()+4, rh );
 	if ( rh != fh )
-	    update( 0, QMIN(fh,rh) - frameWidth() - 2, rw, frameWidth()+4 );
+	    update( 0, qMin(fh,rh) - frameWidth() - 2, rw, frameWidth()+4 );
     }
 }
 
@@ -2257,10 +2244,10 @@ void QtTableView::showOrHideScrollBars()
 void QtTableView::updateTableSize()
 {
     bool updateOn = autoUpdate();
-    setAutoUpdate( FALSE );
+    setAutoUpdate( false );
     int xofs = xOffset();
     xOffs++; //so that setOffset will not return immediately
-    setOffset(xofs,yOffset(),FALSE); //to calculate internal state correctly
+    setOffset(xofs,yOffset(),false); //to calculate internal state correctly
     setAutoUpdate(updateOn);
 
     updateScrollBars( horSteps |  horRange |
