@@ -29,11 +29,7 @@
 
 #include <QDockWidget>
 #include <QTimer>
-#include <QByteArray>
 #include <QLabel>
-#include <QLineEdit>
-#include <QTextStream>
-#include <QSizePolicy>
 #include <QProgressBar>
 #include <QFile>
 #include <QEventLoop>
@@ -59,9 +55,12 @@
 #include <kshortcutsdialog.h>
 #include <ktip.h>
 #include <kmenu.h>
+#include <kmessagebox.h>
 #include <kdebug.h>
 #include <kicon.h>
 #include <kconfiggroup.h>
+#include <kfilterdev.h>
+#include <kmimetype.h>
 
 #if ENABLE_DUMPDOCK
 #include "dumpselection.h"
@@ -72,7 +71,7 @@
 #include "stackselection.h"
 #include "stackbrowser.h"
 #include "tracedata.h"
-#include "globalconfig.h"
+#include "globalguiconfig.h"
 #include "config.h"
 #include "configdlg.h"
 #include "multiview.h"
@@ -94,7 +93,7 @@ TopLevel::TopLevel()
     resetState();
 
     KConfig *kconfig = KGlobal::config().data();
-    GlobalConfig::config()->readOptions();
+    GlobalGUIConfig::config()->readOptions();
 
     createDocks();
 
@@ -126,9 +125,11 @@ TopLevel::TopLevel()
   _showPercentage = GlobalConfig::showPercentage();
   _showExpanded   = GlobalConfig::showExpanded();
   _showCycles     = GlobalConfig::showCycles();
+  _hideTemplates  = GlobalConfig::hideTemplates();
   _taPercentage->setChecked(_showPercentage);
   _taExpanded->setChecked(_showExpanded);
   _taCycles->setChecked(_showCycles);
+  _taHideTemplates->setChecked(_hideTemplates);
 
   setupPartSelection(_partSelection);
 
@@ -361,10 +362,7 @@ void TopLevel::readProperties(const KConfigGroup &c)
 {
   QString traceName = c.readEntry("TraceName");
   if (!traceName.isEmpty()) {
-      TraceData* d = new TraceData(this);
-      int filesLoaded = d->load(traceName);
-      if (filesLoaded >0)
-	  setData(d);
+      openDataFile(traceName);
   }
 }
 
@@ -576,6 +574,20 @@ void TopLevel::createMiscActions()
               "is the option to switch this off.</p>");
   _taCycles->setWhatsThis( hint );
 
+  _taHideTemplates = actionCollection()->add<KToggleAction>("hide_templates");
+  _taHideTemplates->setIcon(KIcon("hidetemplates"));
+  _taHideTemplates->setText(i18n( "Shorten Templates" ));
+  connect(_taHideTemplates, SIGNAL(triggered(bool) ), SLOT( toggleHideTemplates() ));
+  _taHideTemplates->setToolTip(i18n( "Hide Template Parameters in C++ Symbols" ));
+  hint = i18n("<b>Hide Template Parameters in C++ Symbols</b>"
+              "<p>If this is switched on, every symbol displayed will have "
+              "any C++ template parameters hidden, just showing &lt;&gt; "
+              "instead of a potentially nested template parameter.</p>"
+              "<p>In this mode, you can hover the mouse pointer over the "
+              "activated symbol label to show a tooltip with the "
+              "unabbreviated symbol.</p>");
+  _taHideTemplates->setWhatsThis(hint);
+
   KStandardAction::quit(this, SLOT(close()), actionCollection());
   KStandardAction::preferences(this, SLOT(configure()), actionCollection());
   KStandardAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
@@ -649,9 +661,15 @@ void TopLevel::createMiscActions()
   _saCost->setToolTip( hint );
   _saCost->setWhatsThis( hint );
 
-  // A dummy entry forces a minimum size of combobox in toolbar
+  // This is needed because for KDE4, "_saCost->setComboWidth(300);" seems to
+  // have no effect. Instead, list box entry widths are used to determine the
+  // combobox width. However, at KCachegrind startup, we do not have yet
+  // a list of event types, as this depends on the profile data.
+  // In KDE 4.2, we used a translatable string, which did not really work as
+  // the semantic is not known to translators. Instead, we use a
+  // nontranslatable string now...
   QStringList dummyItems;
-  dummyItems << i18n("(Placeholder for list of event types)");
+  dummyItems << "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
   _saCost->setItems(dummyItems);
 
   // cost types are dependent on loaded data, thus KSelectAction
@@ -777,13 +795,8 @@ void TopLevel::setRelativeCost()
 void TopLevel::updateViewsOnChange(int change)
 {
   _partSelection->notifyChange(change);
-  _partSelection->updateView();
-
   _functionSelection->notifyChange(change);
-  _functionSelection->updateView();
-
   _multiView->notifyChange(change);
-  _multiView->updateView();
 }
 
 void TopLevel::setPercentage(bool show)
@@ -831,6 +844,19 @@ void TopLevel::toggleCycles()
   updateViewsOnChange(TraceItemView::configChanged);
 }
 
+void TopLevel::toggleHideTemplates()
+{
+  bool b = _taHideTemplates->isChecked();
+  if (_hideTemplates == b) return;
+  _hideTemplates = b;
+
+  GlobalConfig::setHideTemplates(_hideTemplates);
+
+  _stackSelection->refresh();
+
+  updateViewsOnChange(TraceItemView::configChanged);
+}
+
 void TopLevel::partVisibilityChanged(bool v)
 {
   _partDockShown->setChecked(v);
@@ -916,13 +942,24 @@ void TopLevel::loadTrace(const KUrl& url)
 
     loadTrace(tmpFile);
     KIO::NetAccess::removeTempFile( tmpFile );
+  } else {
+    KMessageBox::error(this, i18n("Could not open the file \"%1\". "
+                                  "Check it exists and you have enough "
+                                  "permissions to read it.", url.prettyUrl()));
   }
 }
 
+/* if file name is ".": load first file found in current directory, but do
+ * not show an error message if nothing could be loaded
+ */
 void TopLevel::loadTrace(QString file)
 {
   if (file.isEmpty()) return;
 
+  bool showError = true;
+  if (file == QString("."))
+      showError = false;
+
   if (_data && _data->parts().count()>0) {
 
     // In new window
@@ -933,10 +970,11 @@ void TopLevel::loadTrace(QString file)
   }
 
   // this constructor enables progress bar callbacks
-  TraceData* d = new TraceData(this);
-  int filesLoaded = d->load(file);
-  if (filesLoaded >0)
-      setData(d);
+  bool loaded = openDataFile(file);
+  if (!loaded && showError)
+      KMessageBox::error(this, i18n("Could not open the file \"%1\". "
+                                    "Check it exists and you have enough "
+                                    "permissions to read it.", file));
 }
 
 
@@ -977,10 +1015,7 @@ void TopLevel::addTrace(QString file)
   }
 
   // this constructor enables progress bar callbacks
-  TraceData* d = new TraceData(this);
-  int filesLoaded = d->load(file);
-  if (filesLoaded >0)
-      setData(d);
+  openDataFile(file);
 }
 
 
@@ -995,7 +1030,11 @@ void TopLevel::loadTraceDelayed()
 {
   if (_loadTraceDelayed.isEmpty()) return;
 
-  loadTrace(_loadTraceDelayed);
+  // if URL scheme is missing (URL is relative), this is a local file
+  if (KUrl::isRelativeUrl(_loadTraceDelayed))
+      loadTrace(_loadTraceDelayed);
+  else
+      loadTrace(KUrl(_loadTraceDelayed));
   _loadTraceDelayed = QString();
 }
 
@@ -1009,10 +1048,7 @@ void TopLevel::reload()
     trace = _data->traceName();
 
   // this also keeps sure we have the same browsing position...
-  TraceData* d = new TraceData(this);
-  int filesLoaded = d->load(trace);
-  if (filesLoaded >0)
-      setData(d);
+  openDataFile(trace);
 }
 
 void TopLevel::exportGraph()
@@ -1023,9 +1059,13 @@ void TopLevel::exportGraph()
   GraphExporter ge(_data, _function, _eventType, _groupType, n);
   ge.writeDot();
 
+#ifdef Q_OS_UNIX
+  // shell commands only work in UNIX
   QString cmd = QString("(dot %1 -Tps > %2.ps; kghostview %3.ps)&")
                 .arg(n).arg(n).arg(n);
-  system(QFile::encodeName( cmd ));
+  if (::system(QFile::encodeName( cmd ))<0)
+	qDebug() << "TopLevel::exportGraph: can not run " << cmd;
+#endif
 }
 
 
@@ -1073,25 +1113,16 @@ bool TopLevel::setEventType(EventType* ct)
   _eventType = ct;
 
   if (ct) {
-      int idx=0;
       QStringList l = _saCost->items();
-      // TODO replace with l.indexOf(ct->longName()) ?
-      for (QStringList::const_iterator it = l.constBegin(); it != l.constEnd(); ++it, ++idx ) {
-	  if (*it == ct->longName())
-	      _saCost->setCurrentItem(idx);
-      }
+      int idx = l.indexOf(ct->longName());
+      if (idx >= 0)
+	  _saCost->setCurrentItem(idx);
   }
 
   _partSelection->setEventType(_eventType);
-  _partSelection->updateView();
-
   _stackSelection->setEventType(_eventType);
-
   _functionSelection->setEventType(_eventType);
-  _functionSelection->updateView();
-
   _multiView->setEventType(_eventType);
-  _multiView->updateView();
 
   updateStatusBar();
 
@@ -1104,26 +1135,15 @@ bool TopLevel::setEventType2(EventType* ct)
   _eventType2 = ct;
 
   QString longName = ct ? ct->longName() : i18n("(Hidden)");
-
-  int idx=0;
   QStringList l = _saCost2->items();
-
-  // TODO replace with indexOf(longName)?
-  for (QStringList::const_iterator it = l.constBegin(); it != l.constEnd(); ++it, ++idx ) {
-    if (*it == longName)
+  int idx = l.indexOf(longName);
+  if (idx >= 0)
       _saCost2->setCurrentItem(idx);
-  }
 
   _partSelection->setEventType2(_eventType2);
-  _partSelection->updateView();
-
   _stackSelection->setEventType2(_eventType2);
-
   _functionSelection->setEventType2(_eventType2);
-  _functionSelection->updateView();
-
   _multiView->setEventType2(_eventType2);
-  _multiView->updateView();
 
   updateStatusBar();
 
@@ -1184,15 +1204,9 @@ bool TopLevel::setGroupType(ProfileContext::Type gt)
     saGroup->setCurrentItem(idx);
 
   _stackSelection->setGroupType(_groupType);
-
   _partSelection->set(_groupType);
-  _partSelection->updateView();
-
   _functionSelection->set(_groupType);
-  _functionSelection->updateView();
-
   _multiView->set(_groupType);
-  _multiView->updateView();
 
   updateStatusBar();
 
@@ -1236,14 +1250,8 @@ bool TopLevel::setFunction(TraceFunction* f)
   _function = f;
 
   _multiView->activate(f);
-  _multiView->updateView();
-
   _functionSelection->activate(f);
-  _functionSelection->updateView();
-
   _partSelection->activate(f);
-  _partSelection->updateView();
-
   _stackSelection->setFunction(_function);
 
   StackBrowser* b = _stackSelection->browser();
@@ -1388,7 +1396,6 @@ void TopLevel::setTraceItemDelayed()
     case ProfileContext::File:
     case ProfileContext::Class:
 	_multiView->activate(_traceItemDelayed);
-	_multiView->updateView();
 	break;
 
 #if 0
@@ -1397,7 +1404,6 @@ void TopLevel::setTraceItemDelayed()
     case ProfileContext::Line:
 	// only for multiview
 	_multiView->activate(_traceItemDelayed);
-	_multiView->updateView();
 	break;
 #endif
 
@@ -1424,14 +1430,10 @@ void TopLevel::setData(TraceData* data)
 
   if (_data) {
     _partSelection->setData(0);
-    _partSelection->updateView();
-
     _stackSelection->setData(0);
-
     _functionSelection->setData(0);
-    _functionSelection->updateView();
     _multiView->setData(0);
-    _multiView->updateView();
+    _multiView->updateView(true);
 
     // we are the owner...
     delete _data;
@@ -1470,14 +1472,12 @@ void TopLevel::setData(TraceData* data)
     _saCost2->setCurrentItem(0);
 
   _partSelection->setData(_data);
-  _partSelection->updateView();
-
   _stackSelection->setData(_data);
-
   _functionSelection->setData(_data);
-  _functionSelection->updateView();
   _multiView->setData(_data);
-  _multiView->updateView();
+  // Force update of _data in all children of _multiView
+  // This is needed to make restoring of activeItem work!
+  _multiView->updateView(true);
 
   /* this is needed to let the other widgets know the types */
   restoreTraceTypes();
@@ -1692,7 +1692,7 @@ void TopLevel::restoreTraceSettings()
   if (!_traceItemDelayed) {
     // function not available any more.. try with "main"
     if (!setFunction("main"))
-      _functionSelection->setTopFunction();
+      _functionSelection->selectTopFunction();
   }
 }
 
@@ -1855,14 +1855,14 @@ void TopLevel::updateStatusBar()
 
 void TopLevel::configure()
 {
-    if (ConfigDlg::configure( (GlobalConfig*) GlobalConfig::config(),
+    if (ConfigDlg::configure( GlobalGUIConfig::config(),
 			      _data, this)) {
-      GlobalConfig::config()->saveOptions();
+      GlobalGUIConfig::config()->saveOptions();
 
     configChanged();
   }
   else
-      GlobalConfig::config()->readOptions();
+      GlobalGUIConfig::config()->readOptions();
 }
 
 bool TopLevel::queryClose()
@@ -1878,7 +1878,8 @@ bool TopLevel::queryExit()
     GlobalConfig::setShowPercentage(_showPercentage);
     GlobalConfig::setShowExpanded(_showExpanded);
     GlobalConfig::setShowCycles(_showCycles);
-    GlobalConfig::config()->saveOptions();
+    GlobalConfig::setHideTemplates(_hideTemplates);
+    GlobalGUIConfig::config()->saveOptions();
 
     saveCurrentState(QString::null);	//krazy:exclude=nullstrassign for old broken gcc
 
@@ -1953,14 +1954,8 @@ void TopLevel::activePartsChangedSlot(const TracePartList& list)
   _activeParts = list;
 
   _partSelection->set(list);
-  _partSelection->updateView();
-
   _multiView->set(list);
-  _multiView->updateView();
-
   _functionSelection->set(list);
-  _functionSelection->updateView();
-
   _stackSelection->refresh();
 
   updateStatusBar();
@@ -1977,15 +1972,13 @@ void TopLevel::partsHideSelectedSlot()
 {
   if (!_data) return;
 
-  TracePart* part;
   TracePartList newHidden, newActive;
-  TracePartList l = _data->parts();
-  for (part=l.first();part;part=l.next()) {
-    if ((_activeParts.findRef(part)>=0) ||
-        (_hiddenParts.findRef(part)>=0))
-      newHidden.append(part);
-    else
-      newActive.append(part);
+  foreach(TracePart* part, _data->parts()) {
+      if (_activeParts.contains(part) ||
+          _hiddenParts.contains(part))
+          newHidden.append(part);
+      else
+          newActive.append(part);
   }
 
   _hiddenParts = newHidden;
@@ -2306,4 +2299,26 @@ void TopLevel::loadWarning(int line, const QString& msg)
 	kWarning() << "Loading" << _filename.ascii() << ":" << line << ": " << msg.ascii();
 }
 
+bool TopLevel::openDataFile(const QString& file)
+{
+    TraceData* d = new TraceData(this);
+    int filesLoaded;
+
+    // see whether this file is compressed, than take the direct route
+    QString mimeType = KMimeType::findByFileContent(file)->name ();
+    QIODevice* compressed = KFilterDev::deviceForFile (file, mimeType, true);
+    if (compressed) {
+        filesLoaded = d->load(compressed, file);
+    } else {
+        // else fallback to string based method that can also find multi-part callgrind data.
+        filesLoaded = d->load(file);
+    }
+    if (filesLoaded > 0) {
+        setData(d);
+        return true;
+    } else {
+        return false;
+    }
+}
+
 #include "toplevel.moc"
