@@ -355,7 +355,7 @@ void EditorTab::replace()
 
     if (!m_view->selectionInTarget().isEmpty())
     {
-        if (_replace && _replace->options()&IGNOREACCELS)
+        if (_replace&&_replace->options()&IGNOREACCELS)
         {
             QString tmp(m_view->selectionInTarget());
             tmp.remove('&');
@@ -375,11 +375,10 @@ void EditorTab::replace()
     // This creates a find-next-prompt dialog if needed.
     {
         _replace = new KReplace(EntryReplaceDialog::instance()->pattern(),EntryReplaceDialog::instance()->replacement(),EntryReplaceDialog::instance()->options(),this,EntryReplaceDialog::instance());
-        connect(_replace,SIGNAL(highlight(QString,int,int)),
-                this,SLOT(highlightFound_(QString,int,int)));
-        connect(_replace,SIGNAL(findNext()),this,SLOT(replaceNext()));
-        connect(_replace,SIGNAL(replace(QString,int,int,int)),
-                this,SLOT(doReplace(QString,int,int,int)));
+        connect(_replace,SIGNAL(highlight(QString,int,int)),    this,SLOT(highlightFound_(QString,int,int)));
+        connect(_replace,SIGNAL(findNext()),                    this,SLOT(replaceNext()));
+        connect(_replace,SIGNAL(replace(QString,int,int,int)),  this,SLOT(doReplace(QString,int,int,int)));
+        connect(_replace,SIGNAL(dialogClosed()),                this,SLOT(cleanupReplace()));
 //         _replace->closeReplaceNextDialog();
     }
 //     else
@@ -516,9 +515,8 @@ void EditorTab::doReplace(const QString &newStr,int offset,int newLen,int remLen
         if (_replace->options()&IGNOREACCELS)
             calcOffsetWithAccels(oldStr,offset,remLen);
 
-        QString tmp=oldStr.mid(offset,remLen);
         pos.offset=offset;
-        m_catalog->push(new DelTextCmd(m_catalog,pos,tmp));
+        m_catalog->push(new DelTextCmd(m_catalog,pos,oldStr.mid(offset,remLen)));
 
         if (newLen)
             m_catalog->push(new InsTextCmd(m_catalog,pos,newStr.mid(offset,newLen)));
@@ -675,7 +673,7 @@ bool EditorTab::findEntryBySourceContext(const QString& source, const QString& c
     DocPosition pos(0);
     do
     {
-        if (m_catalog->source(pos)==source && m_catalog->msgctxt(pos.entry)==ctxt)
+        if (m_catalog->source(pos)==source && m_catalog->context(pos.entry)==QStringList(ctxt))
         {
             gotoEntry(pos);
             return true;
