@@ -1,28 +1,25 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef CLASSGENPAGE_H
 #define CLASSGENPAGE_H
 
-//quicktime class includes
-#include <qwidget.h>
+#include <QtGui/QWidget>
 
-class Q3GroupBox;
+class QGroupBox;
 class QLabel;
-class Q3ButtonGroup;
-class Q3MultiLineEdit;
 class QRadioButton;
 class QCheckBox;
 class KComboBox;
 class KLineEdit;
+class KTextEdit;
 
 class UMLObject;
 class UMLWidget;
@@ -37,25 +34,24 @@ class UMLDoc;
  * @author Paul Hensgen <phensgen@techie.com>
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class ClassGenPage : public QWidget {
+class ClassGenPage : public QWidget
+{
     Q_OBJECT
 public:
 
     /**
-     *  Sets up the ClassGenPage.
-     *
-     *  @param  d       The UMLDoc which controls controls object creation.
-     *  @param  parent  The parent to the ClassGenPage.
-     *  @param  o       The UMLObject to display the properties of.
+     * Sets up the ClassGenPage.
+     * @param  d       The UMLDoc which controls controls object creation.
+     * @param  parent  The parent to the ClassGenPage.
+     * @param  o       The UMLObject to display the properties of.
      */
     ClassGenPage(UMLDoc *d, QWidget *parent, UMLObject * o);
 
     /**
-     *  Sets up the ClassGenPage for an ObjectWidget
-     *
-     *  @param  d       The UMLDoc which controls controls object creation.
-     *  @param  parent  The parent to the ClassGenPage.
-     *  @param  o       The ObjectWidget to display the properties of.
+     * Sets up the ClassGenPage for an ObjectWidget
+     * @param  d       The UMLDoc which controls controls object creation.
+     * @param  parent  The parent to the ClassGenPage.
+     * @param  o       The ObjectWidget to display the properties of.
      */
     ClassGenPage(UMLDoc *d, QWidget *parent, ObjectWidget * o);
 
@@ -70,40 +66,34 @@ public:
     ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget);
 
     /**
-     *  Standard deconstructor.
+     * Standard deconstructor.
      */
     ~ClassGenPage();
 
-    /**
-     *  Will move information from the dialog into the object.
-     *  Call when the ok or apply button is pressed.
-     */
     void updateObject();
-private:
-    Q3GroupBox *m_pDocGB;
-    Q3ButtonGroup       * m_pButtonBG;
-    QLabel * m_pNameL, * m_pInstanceL, * m_pStereoTypeL, * m_pPackageL;
-    KLineEdit * m_pClassNameLE, *m_pInstanceLE, * m_pPackageLE;
-    KComboBox * m_pStereoTypeCB, *m_pPackageCB ;
-    QRadioButton *m_pPublicRB, *m_pPrivateRB, *m_pProtectedRB, *m_pImplementationRB;
-    QCheckBox * m_pMultiCB, * m_pDrawActorCB, * m_pAbstractCB, * m_pDeconCB;
-    Q3MultiLineEdit * m_pDoc;
-    UMLObject * m_pObject;
-    UMLDoc * m_pUmldoc;
-    ObjectWidget * m_pWidget;
-    UMLWidget* m_pInstanceWidget;
-    Q3ButtonGroup* m_pDrawAsBG;
-    QRadioButton* m_pDefaultRB,* m_pFileRB,* m_pLibraryRB,* m_pTableRB;
-    QCheckBox* m_pExecutableCB;
 
-    void insertStereotype(const QString& type, int index = -1);
+private:
+    UMLObject * m_pObject;
+    ObjectWidget * m_pWidget;
+    UMLWidget * m_pInstanceWidget;
+    UMLDoc * m_pUmldoc;
+
+    QGroupBox * m_pDocGB;
+    QGroupBox * m_pButtonGB;
+    QLabel * m_pNameL, * m_pInstanceL, * m_pStereoTypeL, * m_pPackageL;
+    KLineEdit * m_pClassNameLE, * m_pInstanceLE, * m_pPackageLE;
+    KComboBox * m_pStereoTypeCB, * m_pPackageCB ;
+    QRadioButton * m_pPublicRB, * m_pPrivateRB, * m_pProtectedRB, * m_pImplementationRB;
+    QCheckBox * m_pMultiCB, * m_pDrawActorCB, * m_pAbstractCB, * m_pDeconCB;
+    KTextEdit * m_pDoc;
+    QGroupBox * m_pDrawAsGB;
+    QRadioButton * m_pDefaultRB, * m_pFileRB, * m_pLibraryRB, * m_pTableRB;
+    QCheckBox * m_pExecutableCB;
+
+    void insertStereotypesSorted(const QString& type);
 
 public slots:
-    /**
-     *  When the draw as actor check box is toggled, the draw
-     *  as multi instance need to be enabled/disabled.  They
-     *  both can't be available at the same time.
-     */
+
     void slotActorToggled( bool state );
 };
 
