@@ -20,10 +20,11 @@
 #define UMLVIEWLIST_H
 
 //#include "umlview.h"
+#include <QList>
 
 class UMLView;
 
-typedef QPtrList<UMLView> UMLViewList;
-typedef QPtrListIterator<UMLView> UMLViewListIt;
+typedef QList<UMLView*> UMLViewList;
+typedef QListIterator<UMLView*> UMLViewListIt;
 
 #endif
